file

package
v0.5.10 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 21, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Snoop

func Snoop(path meowrt.Value) meowrt.Value

Snoop reads the entire contents of a file and returns it as a String.

func Stalk

func Stalk(path meowrt.Value) meowrt.Value

Stalk reads a file line by line and returns a List of Strings.

Types

This section is empty.

Jump to