Documentation
¶
Index ¶
- func Catwalk(args ...meowrt.Value) meowrt.Value
- func Expect(args ...meowrt.Value) meowrt.Value
- func Judge(args ...meowrt.Value) meowrt.Value
- func Refuse(args ...meowrt.Value) meowrt.Value
- func Report(args ...meowrt.Value) meowrt.Value
- func Reset(w io.Writer, exit func(int))
- func Run(args ...meowrt.Value) meowrt.Value
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Catwalk ¶
Catwalk executes a named function, captures its stdout output, and compares it with the expected output string. This is the Meow equivalent of Go's Example tests with // Output: comments. Usage: Catwalk(name, fn, expected)
func Expect ¶
Expect asserts that two values are equal (by String representation). Usage: expect(actual, expected) or expect(actual, expected, "message")
func Judge ¶
Judge asserts that a condition is truthy. Usage: judge(condition) or judge(condition, "message")
func Refuse ¶
Refuse asserts that a condition is falsy. Usage: refuse(condition) or refuse(condition, "message")
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.